@@ -11,8 +11,6 @@ class StatCounter(object):
     clients = 0
     # 客户端请求数
     client_req = 0
-    # 客户端回应数
-    client_rsp = 0
     # worker请求数
     worker_req_counter = None
     # 丢弃的任务
