@@ -36,7 +36,7 @@ DEFAULT_CONFIG = dict(
     BOX_CLASS='netkit.box.Box',
 
     # task class
-    TASK_CLASS='maple.task.Task',
+    TASK_CLASS='maple.Task',
 
     # master class
     MASTER_CLASS='peony.master.Master',
